@@ -16,10 +16,10 @@ use overload    #
   q[""] => sub {
     return $_[0]->path;
   },
-  q[cmp] => sub {
+  'cmp' => sub {
     return !$_[2] ? $_[0]->path cmp $_[1] : $_[1] cmp $_[0]->path;
   },
-  q[0+] => sub {
+  '0+' => sub {
     return refaddr $_[0];
   },
   fallback => undef;
